@@ -12,8 +12,8 @@ use std::{
 
 use filetime::{set_file_mtime, FileTime};
 use fs_err as fs;
-use humansize::{format_size, DECIMAL};
 use same_file::Handle;
+use ubyte::ToByteUnit;
 use zip::{self, read::ZipFile, DateTime, ZipArchive};
 
 use crate::{
@@ -21,21 +21,21 @@ use crate::{
     info,
     list::FileInArchive,
     utils::{
-        self, cd_into_same_dir_as, get_invalid_utf8_paths, pretty_format_list_of_paths, strip_cur_dir, to_utf,
-        FileVisibilityPolicy,
+        self, cd_into_same_dir_as, get_invalid_utf8_paths, pretty_format_list_of_paths, strip_cur_dir,
+        EscapedPathDisplay, FileVisibilityPolicy,
     },
     warning,
 };
 
 /// Unpacks the archive given by `archive` into the folder given by `output_folder`.
 /// Assumes that output_folder is empty
-pub fn unpack_archive<R>(mut archive: ZipArchive<R>, output_folder: &Path) -> crate::Result<Vec<PathBuf>>
+pub fn unpack_archive<R>(mut archive: ZipArchive<R>, output_folder: &Path, quiet: bool) -> crate::Result<usize>
 where
     R: Read + Seek,
 {
     assert!(output_folder.read_dir().expect("dir exists").count() == 0);
 
-    let mut unpacked_files = Vec::with_capacity(archive.len());
+    let mut unpacked_files = 0;
 
     for idx in 0..archive.len() {
         let mut file = archive.by_index(idx)?;
@@ -54,7 +54,9 @@ where
                 // importance for most users, but would generate lots of
                 // spoken text for users using screen readers, braille displays
                 // and so on
-                info!(inaccessible, "File {} extracted to \"{}\"", idx, file_path.display());
+                if !quiet {
+                    info!(inaccessible, "File {} extracted to \"{}\"", idx, file_path.display());
+                }
                 fs::create_dir_all(&file_path)?;
             }
             _is_file @ false => {
@@ -66,12 +68,14 @@ where
                 let file_path = strip_cur_dir(file_path.as_path());
 
                 // same reason is in _is_dir: long, often not needed text
-                info!(
-                    inaccessible,
-                    "{:?} extracted. ({})",
-                    file_path.display(),
-                    format_size(file.size(), DECIMAL),
-                );
+                if !quiet {
+                    info!(
+                        inaccessible,
+                        "{:?} extracted. ({})",
+                        file_path.display(),
+                        file.size().bytes()
+                    );
+                }
 
                 let mut output_file = fs::File::create(file_path)?;
                 io::copy(&mut file, &mut output_file)?;
@@ -83,7 +87,7 @@ where
         #[cfg(unix)]
         unix_set_permissions(&file_path, &file)?;
 
-        unpacked_files.push(file_path);
+        unpacked_files += 1;
     }
 
     Ok(unpacked_files)
@@ -135,6 +139,7 @@ pub fn build_archive_from_paths<W>(
     output_path: &Path,
     writer: W,
     file_visibility_policy: FileVisibilityPolicy,
+    quiet: bool,
 ) -> crate::Result<W>
 where
     W: Write + Seek,
@@ -185,7 +190,9 @@ where
             // little importance for most users, but would generate lots of
             // spoken text for users using screen readers, braille displays
             // and so on
-            info!(inaccessible, "Compressing '{}'.", to_utf(path));
+            if !quiet {
+                info!(inaccessible, "Compressing '{}'.", EscapedPathDisplay::new(path));
+            }
 
             let metadata = match path.metadata() {
                 Ok(metadata) => metadata,
