@@ -18,7 +18,8 @@ use crate::{
     info,
     list::ListOptions,
     utils::{
-        self, pretty_format_list_of_paths, to_utf, try_infer_extension, user_wants_to_continue, FileVisibilityPolicy,
+        self, pretty_format_list_of_paths, to_utf, try_infer_extension, user_wants_to_continue, EscapedPathDisplay,
+        FileVisibilityPolicy,
     },
     warning, Opts, QuestionAction, QuestionPolicy, Subcommand,
 };
@@ -67,6 +68,31 @@ fn build_archive_file_suggestion(path: &Path, suggested_extension: &str) -> Opti
     None
 }
 
+/// In the context of listing archives, this function checks if `ouch` was told to list
+/// the contents of a compressed file that is not an archive
+fn check_for_non_archive_formats(files: &[PathBuf], formats: &[Vec<Extension>]) -> crate::Result<()> {
+    let mut not_archives = files
+        .iter()
+        .zip(formats)
+        .filter(|(_, formats)| !formats.first().map(Extension::is_archive).unwrap_or(false))
+        .map(|(path, _)| path)
+        .peekable();
+
+    if not_archives.peek().is_some() {
+        let not_archives: Vec<_> = not_archives.collect();
+        let error = FinalError::with_title("Cannot list archive contents")
+            .detail("Only archives can have their contents listed")
+            .detail(format!(
+                "Files are not archives: {}",
+                pretty_format_list_of_paths(&not_archives)
+            ));
+
+        return Err(error.into());
+    }
+
+    Ok(())
+}
+
 /// This function checks what command needs to be run and performs A LOT of ahead-of-time checks
 /// to assume everything is OK.
 ///
@@ -90,7 +116,7 @@ pub fn run(
             let formats = extension::extensions_from_path(&output_path);
 
             let first_format = formats.first().ok_or_else(|| {
-                let output_path = to_utf(&output_path);
+                let output_path = EscapedPathDisplay::new(&output_path);
                 FinalError::with_title(format!("Cannot compress to '{output_path}'."))
                     .detail("You shall supply the compression format")
                     .hint("Try adding supported extensions (see --help):")
@@ -113,43 +139,43 @@ pub fn run(
                 // To          file.tar.bz.xz
                 let suggested_output_path = build_archive_file_suggestion(&output_path, ".tar")
                     .expect("output path should contain a compression format");
-                let output_path = to_utf(&output_path);
+                let output_path = EscapedPathDisplay::new(&output_path);
                 let first_detail_message = if is_multiple_inputs {
                     "You are trying to compress multiple files."
                 } else {
                     "You are trying to compress a folder."
                 };
 
-                let error = FinalError::with_title(format!("Cannot compress to '{}'.", output_path))
+                let error = FinalError::with_title(format!("Cannot compress to '{output_path}'."))
                     .detail(first_detail_message)
                     .detail(format!(
-                        "The compression format '{}' does not accept multiple files.",
-                        &formats[0]
+                        "The compression format '{first_format}' does not accept multiple files.",
                     ))
                     .detail("Formats that bundle files into an archive are .tar and .zip.")
-                    .hint(format!("Try inserting '.tar' or '.zip' before '{}'.", &formats[0]))
-                    .hint(format!("From: {}", output_path))
-                    .hint(format!("To:   {}", suggested_output_path));
+                    .hint(format!("Try inserting '.tar' or '.zip' before '{first_format}'."))
+                    .hint(format!("From: {output_path}"))
+                    .hint(format!("To:   {suggested_output_path}"));
 
                 return Err(error.into());
             }
 
             if let Some(format) = formats.iter().skip(1).find(|format| format.is_archive()) {
-                let error = FinalError::with_title(format!("Cannot compress to '{}'.", to_utf(&output_path)))
-                    .detail(format!("Found the format '{}' in an incorrect position.", format))
-                    .detail(format!(
-                        "'{}' can only be used at the start of the file extension.",
-                        format
-                    ))
-                    .hint(format!(
-                        "If you wish to compress multiple files, start the extension with '{}'.",
-                        format
-                    ))
-                    .hint(format!(
-                        "Otherwise, remove the last '{}' from '{}'.",
-                        format,
-                        to_utf(&output_path)
-                    ));
+                let error = FinalError::with_title(format!(
+                    "Cannot compress to '{}'.",
+                    EscapedPathDisplay::new(&output_path)
+                ))
+                .detail(format!("Found the format '{format}' in an incorrect position."))
+                .detail(format!(
+                    "'{format}' can only be used at the start of the file extension."
+                ))
+                .hint(format!(
+                    "If you wish to compress multiple files, start the extension with '{format}'."
+                ))
+                .hint(format!(
+                    "Otherwise, remove the last '{}' from '{}'.",
+                    format,
+                    EscapedPathDisplay::new(&output_path)
+                ));
 
                 return Err(error.into());
             }
@@ -164,6 +190,7 @@ pub fn run(
                 formats,
                 output_file,
                 &output_path,
+                args.quiet,
                 question_policy,
                 file_visibility_policy,
             );
@@ -181,7 +208,10 @@ pub fn run(
                 // out that we left a possibly CORRUPTED file at `output_path`
                 if utils::remove_file_or_dir(&output_path).is_err() {
                     eprintln!("{red}FATAL ERROR:\n", red = *colors::RED);
-                    eprintln!("  Ouch failed to delete the file '{}'.", to_utf(&output_path));
+                    eprintln!(
+                        "  Ouch failed to delete the file '{}'.",
+                        EscapedPathDisplay::new(&output_path)
+                    );
                     eprintln!("  Please delete it manually.");
                     eprintln!("  This file is corrupted if compression didn't finished.");
 
@@ -214,7 +244,7 @@ pub fn run(
                 .map(|(input_path, _)| PathBuf::from(input_path))
                 .collect();
 
-            if !files_missing_format.is_empty() {
+            if let Some(path) = files_missing_format.first() {
                 let error = FinalError::with_title("Cannot decompress files without extensions")
                     .detail(format!(
                         "Files without supported extensions: {}",
@@ -227,7 +257,7 @@ pub fn run(
                     .hint("Or overwrite this option with the '--format' flag:")
                     .hint(format!(
                         "  ouch decompress {} --format tar.gz",
-                        to_utf(&files_missing_format[0])
+                        EscapedPathDisplay::new(path),
                     ));
 
                 return Err(error.into());
@@ -236,10 +266,6 @@ pub fn run(
             // The directory that will contain the output files
             // We default to the current directory if the user didn't specify an output directory with --dir
             let output_dir = if let Some(dir) = output_dir {
-                if !utils::clear_path(&dir, question_policy)? {
-                    // User doesn't want to overwrite
-                    return Ok(());
-                }
                 utils::create_dir_if_non_existent(&dir)?;
                 dir
             } else {
@@ -248,14 +274,21 @@ pub fn run(
 
             for ((input_path, formats), file_name) in files.iter().zip(formats).zip(output_paths) {
                 let output_file_path = output_dir.join(file_name); // Path used by single file format archives
-                decompress_file(input_path, formats, &output_dir, output_file_path, question_policy)?;
+                decompress_file(
+                    input_path,
+                    formats,
+                    &output_dir,
+                    output_file_path,
+                    question_policy,
+                    args.quiet,
+                )?;
             }
         }
         Subcommand::List { archives: files, tree } => {
             let mut formats = vec![];
 
             for path in files.iter() {
-                let (_, file_formats) = extension::separate_known_extensions_from_name(path);
+                let file_formats = extension::extensions_from_path(path);
                 formats.push(file_formats);
             }
 
@@ -263,23 +296,8 @@ pub fn run(
                 return Ok(());
             }
 
-            let not_archives: Vec<PathBuf> = files
-                .iter()
-                .zip(&formats)
-                .filter(|(_, formats)| !formats.first().map(Extension::is_archive).unwrap_or(false))
-                .map(|(path, _)| path.clone())
-                .collect();
-
-            if !not_archives.is_empty() {
-                let error = FinalError::with_title("Cannot list archive contents")
-                    .detail("Only archives can have their contents listed")
-                    .detail(format!(
-                        "Files are not archives: {}",
-                        pretty_format_list_of_paths(&not_archives)
-                    ));
-
-                return Err(error.into());
-            }
+            // Ensure we were not told to list the content of a non-archive compressed file
+            check_for_non_archive_formats(&files, &formats)?;
 
             let list_options = ListOptions { tree };
 
